<?php

declare(strict_types=1);

namespace Kylin\Agriculture\Enums;

/**
 * 地块类型枚举
 */
enum PlotType: string
{
    case GREENHOUSE = 'greenhouse';
    case FIELD = 'field';

    public function label(): string
    {
        return match ($this) {
            self::GREENHOUSE => '大棚',
            self::FIELD => '露地',
        };
    }
}
