<?php

declare(strict_types=1);

namespace Kylin\Agriculture\Enums;

/**
 * 农事记录类型枚举
 */
enum FarmRecordType: string
{
    case FERTILIZE = 'fertilize';
    case IRRIGATE = 'irrigate';
    case WEED = 'weed';
    case HARVEST = 'harvest';
    case SPRAY = 'spray';
    case OTHER = 'other';

    public function label(): string
    {
        return match ($this) {
            self::FERTILIZE => '施肥',
            self::IRRIGATE => '灌溉',
            self::WEED => '除草',
            self::HARVEST => '采收',
            self::SPRAY => '喷药',
            self::OTHER => '其他',
        };
    }
}
