<?php

declare(strict_types=1);

namespace Kylin\Agriculture\Enums;

/**
 * 物料日志类型枚举
 */
enum MaterialLogType: string
{
    case IN = 'in';
    case OUT = 'out';

    public function label(): string
    {
        return match ($this) {
            self::IN => '入库',
            self::OUT => '出库',
        };
    }
}
