<?php

use Illuminate\Support\Facades\Route;

// 传感器数据上报接口（供网关调用）
Route::prefix('v1/agriculture')->group(function () {
    Route::post('sensor/data', [\Kylin\Agriculture\Http\Controllers\SensorDataController::class, 'store']);
});
